# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/uom.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16v1/utilities/uom.proto\x12!pro.omni.oms.api.v1.utilities.uom\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xcc\x01\n\x03Uom\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x10\n\x08rounding\x18\x06 \x01(\x01\x12*\n\x06\x61\x63tive\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x08 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x98\x01\n\x10UomCreateRequest\x12\x10\n\x08\x63\x61tegory\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x10\n\x08rounding\x18\x05 \x01(\x01\x12\x36\n\x07\x63ontext\x18\x06 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x93\x01\n\x11UomCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x33\n\x03uom\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.utilities.uom.Uom"\xec\x02\n\x0eUomReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xcd\x01\n\x0fUomReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x34\n\x04uoms\x18\x03 \x03(\x0b\x32&.pro.omni.oms.api.v1.utilities.uom.Uom"\x7f\n\x10UomUpdateRequest\x12\x33\n\x03uom\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.utilities.uom.Uom\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x93\x01\n\x11UomUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x33\n\x03uom\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.utilities.uom.Uom"V\n\x10UomDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"^\n\x11UomDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xee\x03\n\nUomService\x12x\n\tUomCreate\x12\x33.pro.omni.oms.api.v1.utilities.uom.UomCreateRequest\x1a\x34.pro.omni.oms.api.v1.utilities.uom.UomCreateResponse"\x00\x12r\n\x07UomRead\x12\x31.pro.omni.oms.api.v1.utilities.uom.UomReadRequest\x1a\x32.pro.omni.oms.api.v1.utilities.uom.UomReadResponse"\x00\x12x\n\tUomUpdate\x12\x33.pro.omni.oms.api.v1.utilities.uom.UomUpdateRequest\x1a\x34.pro.omni.oms.api.v1.utilities.uom.UomUpdateResponse"\x00\x12x\n\tUomDelete\x12\x33.pro.omni.oms.api.v1.utilities.uom.UomDeleteRequest\x1a\x34.pro.omni.oms.api.v1.utilities.uom.UomDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.uom_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_UOM"]._serialized_start = 113
    _globals["_UOM"]._serialized_end = 317
    _globals["_UOMCREATEREQUEST"]._serialized_start = 320
    _globals["_UOMCREATEREQUEST"]._serialized_end = 472
    _globals["_UOMCREATERESPONSE"]._serialized_start = 475
    _globals["_UOMCREATERESPONSE"]._serialized_end = 622
    _globals["_UOMREADREQUEST"]._serialized_start = 625
    _globals["_UOMREADREQUEST"]._serialized_end = 989
    _globals["_UOMREADRESPONSE"]._serialized_start = 992
    _globals["_UOMREADRESPONSE"]._serialized_end = 1197
    _globals["_UOMUPDATEREQUEST"]._serialized_start = 1199
    _globals["_UOMUPDATEREQUEST"]._serialized_end = 1326
    _globals["_UOMUPDATERESPONSE"]._serialized_start = 1329
    _globals["_UOMUPDATERESPONSE"]._serialized_end = 1476
    _globals["_UOMDELETEREQUEST"]._serialized_start = 1478
    _globals["_UOMDELETEREQUEST"]._serialized_end = 1564
    _globals["_UOMDELETERESPONSE"]._serialized_start = 1566
    _globals["_UOMDELETERESPONSE"]._serialized_end = 1660
    _globals["_UOMSERVICE"]._serialized_start = 1663
    _globals["_UOMSERVICE"]._serialized_end = 2157
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delivery_time.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.rules import delivery_method_pb2 as v1_dot_rules_dot_delivery__method__pb2
from omni.pro.protos.v1.rules import warehouse_pb2 as v1_dot_rules_dot_warehouse__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1cv1/rules/delivery_time.proto\x12\'pro.omni.oms.api.v1.rules.delivery_time\x1a\x11\x63ommon/base.proto\x1a\x1ev1/rules/delivery_method.proto\x1a\x18v1/rules/warehouse.proto"\xb6\x03\n\x0c\x44\x65liveryTime\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12V\n\x13\x64\x65livery_method_ids\x18\x03 \x03(\x0b\x32\x39.pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethod\x12\x45\n\rwarehouse_ids\x18\x04 \x03(\x0b\x32..pro.omni.oms.api.v1.rules.warehouse.Warehouse\x12\x1d\n\x15locality_available_id\x18\x05 \x01(\t\x12\x44\n\ttime_type\x18\x06 \x01(\x0e\x32\x31.pro.omni.oms.api.v1.rules.delivery_time.TimeType\x12\x11\n\tvalue_min\x18\x07 \x01(\t\x12\x11\n\tvalue_max\x18\x08 \x01(\t\x12\x11\n\tinversely\x18\t \x01(\x08\x12\x0e\n\x06\x61\x63tive\x18\n \x01(\x08\x12?\n\x0cobject_audit\x18\x0b \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xff\x01\n\x19\x44\x65liveryTimeCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1d\n\x15locality_available_id\x18\x02 \x01(\t\x12\x44\n\ttime_type\x18\x03 \x01(\x0e\x32\x31.pro.omni.oms.api.v1.rules.delivery_time.TimeType\x12\x11\n\tvalue_min\x18\x04 \x01(\t\x12\x11\n\tvalue_max\x18\x05 \x01(\t\x12\x11\n\tinversely\x18\x06 \x01(\x08\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb5\x01\n\x1a\x44\x65liveryTimeCreateResponse\x12L\n\rdelivery_time\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTime\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf5\x02\n\x17\x44\x65liveryTimeReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xef\x01\n\x18\x44\x65liveryTimeReadResponse\x12M\n\x0e\x64\x65livery_times\x18\x01 \x03(\x0b\x32\x35.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTime\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xa1\x01\n\x19\x44\x65liveryTimeUpdateRequest\x12L\n\rdelivery_time\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTime\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb5\x01\n\x1a\x44\x65liveryTimeUpdateResponse\x12L\n\rdelivery_time\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTime\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"_\n\x19\x44\x65liveryTimeDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"g\n\x1a\x44\x65liveryTimeDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard*9\n\x08TimeType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07MINUTES\x10\x01\x12\t\n\x05HOURS\x10\x02\x12\x08\n\x04\x44\x41YS\x10\x03\x32\x97\x05\n\x13\x44\x65liveryTimeService\x12\x9f\x01\n\x12\x44\x65liveryTimeCreate\x12\x42.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeCreateRequest\x1a\x43.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeCreateResponse"\x00\x12\x99\x01\n\x10\x44\x65liveryTimeRead\x12@.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeReadRequest\x1a\x41.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeReadResponse"\x00\x12\x9f\x01\n\x12\x44\x65liveryTimeUpdate\x12\x42.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeUpdateRequest\x1a\x43.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeUpdateResponse"\x00\x12\x9f\x01\n\x12\x44\x65liveryTimeDelete\x12\x42.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeDeleteRequest\x1a\x43.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delivery_time_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_TIMETYPE"]._serialized_start = 2201
    _globals["_TIMETYPE"]._serialized_end = 2258
    _globals["_DELIVERYTIME"]._serialized_start = 151
    _globals["_DELIVERYTIME"]._serialized_end = 589
    _globals["_DELIVERYTIMECREATEREQUEST"]._serialized_start = 592
    _globals["_DELIVERYTIMECREATEREQUEST"]._serialized_end = 847
    _globals["_DELIVERYTIMECREATERESPONSE"]._serialized_start = 850
    _globals["_DELIVERYTIMECREATERESPONSE"]._serialized_end = 1031
    _globals["_DELIVERYTIMEREADREQUEST"]._serialized_start = 1034
    _globals["_DELIVERYTIMEREADREQUEST"]._serialized_end = 1407
    _globals["_DELIVERYTIMEREADRESPONSE"]._serialized_start = 1410
    _globals["_DELIVERYTIMEREADRESPONSE"]._serialized_end = 1649
    _globals["_DELIVERYTIMEUPDATEREQUEST"]._serialized_start = 1652
    _globals["_DELIVERYTIMEUPDATEREQUEST"]._serialized_end = 1813
    _globals["_DELIVERYTIMEUPDATERESPONSE"]._serialized_start = 1816
    _globals["_DELIVERYTIMEUPDATERESPONSE"]._serialized_end = 1997
    _globals["_DELIVERYTIMEDELETEREQUEST"]._serialized_start = 1999
    _globals["_DELIVERYTIMEDELETEREQUEST"]._serialized_end = 2094
    _globals["_DELIVERYTIMEDELETERESPONSE"]._serialized_start = 2096
    _globals["_DELIVERYTIMEDELETERESPONSE"]._serialized_end = 2199
    _globals["_DELIVERYTIMESERVICE"]._serialized_start = 2261
    _globals["_DELIVERYTIMESERVICE"]._serialized_end = 2924
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/warehouse_hierarchy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.rules import location_pb2 as v1_dot_rules_dot_location__pb2
from omni.pro.protos.v1.rules import warehouse_pb2 as v1_dot_rules_dot_warehouse__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n"v1/rules/warehouse_hierarchy.proto\x12-pro.omni.oms.api.v1.rules.warehouse_hierarchy\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x18v1/rules/warehouse.proto\x1a\x17v1/rules/location.proto"\xf1\x02\n\x12WarehouseHierarchy\x12\n\n\x02id\x18\x01 \x01(\t\x12\x41\n\twarehouse\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.v1.rules.warehouse.Warehouse\x12>\n\x08location\x18\t \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.location.Location\x12\x19\n\x11quantity_security\x18\x04 \x01(\x02\x12\x10\n\x08sequence\x18\x05 \x01(\x05\x12\x32\n\x0esequence_order\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x06\x61\x63tive\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x08 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xe5\x01\n\x1fWarehouseHierarchyCreateRequest\x12\x14\n\x0cwarehouse_id\x18\x01 \x01(\t\x12\x13\n\x0blocation_id\x18\x02 \x01(\t\x12\x19\n\x11quantity_security\x18\x03 \x01(\x02\x12\x10\n\x08sequence\x18\x04 \x01(\x05\x12\x32\n\x0esequence_order\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x07\x63ontext\x18\x06 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xcd\x01\n WarehouseHierarchyCreateResponse\x12^\n\x13warehouse_hierarchy\x18\x01 \x01(\x0b\x32\x41.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchy\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xfb\x02\n\x1dWarehouseHierarchyReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x87\x02\n\x1eWarehouseHierarchyReadResponse\x12_\n\x14warehouses_hierarchy\x18\x01 \x03(\x0b\x32\x41.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchy\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xb9\x01\n\x1fWarehouseHierarchyUpdateRequest\x12^\n\x13warehouse_hierarchy\x18\x01 \x01(\x0b\x32\x41.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchy\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xcd\x01\n WarehouseHierarchyUpdateResponse\x12^\n\x13warehouse_hierarchy\x18\x01 \x01(\x0b\x32\x41.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchy\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"e\n\x1fWarehouseHierarchyDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"m\n WarehouseHierarchyDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\x95\x06\n\x19WarehouseHierarchyService\x12\xbd\x01\n\x18WarehouseHierarchyCreate\x12N.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyCreateRequest\x1aO.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyCreateResponse"\x00\x12\xb7\x01\n\x16WarehouseHierarchyRead\x12L.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyReadRequest\x1aM.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyReadResponse"\x00\x12\xbd\x01\n\x18WarehouseHierarchyUpdate\x12N.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyUpdateRequest\x1aO.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyUpdateResponse"\x00\x12\xbd\x01\n\x18WarehouseHierarchyDelete\x12N.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyDeleteRequest\x1aO.pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.warehouse_hierarchy_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_WAREHOUSEHIERARCHY"]._serialized_start = 188
    _globals["_WAREHOUSEHIERARCHY"]._serialized_end = 557
    _globals["_WAREHOUSEHIERARCHYCREATEREQUEST"]._serialized_start = 560
    _globals["_WAREHOUSEHIERARCHYCREATEREQUEST"]._serialized_end = 789
    _globals["_WAREHOUSEHIERARCHYCREATERESPONSE"]._serialized_start = 792
    _globals["_WAREHOUSEHIERARCHYCREATERESPONSE"]._serialized_end = 997
    _globals["_WAREHOUSEHIERARCHYREADREQUEST"]._serialized_start = 1000
    _globals["_WAREHOUSEHIERARCHYREADREQUEST"]._serialized_end = 1379
    _globals["_WAREHOUSEHIERARCHYREADRESPONSE"]._serialized_start = 1382
    _globals["_WAREHOUSEHIERARCHYREADRESPONSE"]._serialized_end = 1645
    _globals["_WAREHOUSEHIERARCHYUPDATEREQUEST"]._serialized_start = 1648
    _globals["_WAREHOUSEHIERARCHYUPDATEREQUEST"]._serialized_end = 1833
    _globals["_WAREHOUSEHIERARCHYUPDATERESPONSE"]._serialized_start = 1836
    _globals["_WAREHOUSEHIERARCHYUPDATERESPONSE"]._serialized_end = 2041
    _globals["_WAREHOUSEHIERARCHYDELETEREQUEST"]._serialized_start = 2043
    _globals["_WAREHOUSEHIERARCHYDELETEREQUEST"]._serialized_end = 2144
    _globals["_WAREHOUSEHIERARCHYDELETERESPONSE"]._serialized_start = 2146
    _globals["_WAREHOUSEHIERARCHYDELETERESPONSE"]._serialized_end = 2255
    _globals["_WAREHOUSEHIERARCHYSERVICE"]._serialized_start = 2258
    _globals["_WAREHOUSEHIERARCHYSERVICE"]._serialized_end = 3047
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/picking_type.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.stock import location_pb2 as v1_dot_stock_dot_location__pb2
from omni.pro.protos.v1.stock import sequence_pb2 as v1_dot_stock_dot_sequence__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1bv1/stock/picking_type.proto\x12&pro.omni.oms.api.v1.stock.picking_type\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x17v1/stock/sequence.proto\x1a\x17v1/stock/location.proto"\xf9\x04\n\x0bPickingType\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rsequence_code\x18\x03 \x01(\t\x12\x14\n\x0cwarehouse_id\x18\x04 \x01(\x05\x12\x0c\n\x04\x63ode\x18\x05 \x01(\t\x12\x1e\n\x16return_picking_type_id\x18\x06 \x01(\x05\x12\x33\n\x0fshow_operations\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x31\n\rshow_reserved\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12M\n\x17\x64\x65\x66\x61ult_location_src_id\x18\t \x01(\x0b\x32,.pro.omni.oms.api.v1.stock.location.Location\x12N\n\x18\x64\x65\x66\x61ult_location_dest_id\x18\n \x01(\x0b\x32,.pro.omni.oms.api.v1.stock.location.Location\x12\x41\n\x0bsequence_id\x18\x0b \x01(\x0b\x32,.pro.omni.oms.api.v1.stock.sequence.Sequence\x12\x0f\n\x07\x62\x61rcode\x18\x0c \x01(\t\x12\x1a\n\x12reservation_method\x18\r \x01(\t\x12\x11\n\ttype_code\x18\x0e \x01(\t\x12*\n\x06\x61\x63tive\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x10 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xbb\x03\n\x18PickingTypeCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rsequence_code\x18\x02 \x01(\t\x12\x14\n\x0cwarehouse_id\x18\x03 \x01(\x05\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12\x1e\n\x16return_picking_type_id\x18\x05 \x01(\x05\x12\x33\n\x0fshow_operations\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x31\n\rshow_reserved\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1f\n\x17\x64\x65\x66\x61ult_location_src_id\x18\x08 \x01(\x05\x12 \n\x18\x64\x65\x66\x61ult_location_dest_id\x18\t \x01(\x05\x12\x0f\n\x07\x62\x61rcode\x18\n \x01(\t\x12\x1a\n\x12reservation_method\x18\x0b \x01(\t\x12\x11\n\ttype_code\x18\x0c \x01(\t\x12\x13\n\x0bsequence_id\x18\r \x01(\x05\x12\x36\n\x07\x63ontext\x18\x0e \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb1\x01\n\x19PickingTypeCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12I\n\x0cpicking_type\x18\x02 \x01(\x0b\x32\x33.pro.omni.oms.api.v1.stock.picking_type.PickingType"\xf4\x02\n\x16PickingTypeReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xeb\x01\n\x17PickingTypeReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12J\n\rpicking_types\x18\x03 \x03(\x0b\x32\x33.pro.omni.oms.api.v1.stock.picking_type.PickingType"\x9d\x01\n\x18PickingTypeUpdateRequest\x12I\n\x0cpicking_type\x18\x01 \x01(\x0b\x32\x33.pro.omni.oms.api.v1.stock.picking_type.PickingType\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb1\x01\n\x19PickingTypeUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12I\n\x0cpicking_type\x18\x02 \x01(\x0b\x32\x33.pro.omni.oms.api.v1.stock.picking_type.PickingType"^\n\x18PickingTypeDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"f\n\x19PickingTypeDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\x82\x05\n\x12PickingTypeService\x12\x9a\x01\n\x11PickingTypeCreate\x12@.pro.omni.oms.api.v1.stock.picking_type.PickingTypeCreateRequest\x1a\x41.pro.omni.oms.api.v1.stock.picking_type.PickingTypeCreateResponse"\x00\x12\x94\x01\n\x0fPickingTypeRead\x12>.pro.omni.oms.api.v1.stock.picking_type.PickingTypeReadRequest\x1a?.pro.omni.oms.api.v1.stock.picking_type.PickingTypeReadResponse"\x00\x12\x9a\x01\n\x11PickingTypeUpdate\x12@.pro.omni.oms.api.v1.stock.picking_type.PickingTypeUpdateRequest\x1a\x41.pro.omni.oms.api.v1.stock.picking_type.PickingTypeUpdateResponse"\x00\x12\x9a\x01\n\x11PickingTypeDelete\x12@.pro.omni.oms.api.v1.stock.picking_type.PickingTypeDeleteRequest\x1a\x41.pro.omni.oms.api.v1.stock.picking_type.PickingTypeDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.picking_type_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_PICKINGTYPE"]._serialized_start = 173
    _globals["_PICKINGTYPE"]._serialized_end = 806
    _globals["_PICKINGTYPECREATEREQUEST"]._serialized_start = 809
    _globals["_PICKINGTYPECREATEREQUEST"]._serialized_end = 1252
    _globals["_PICKINGTYPECREATERESPONSE"]._serialized_start = 1255
    _globals["_PICKINGTYPECREATERESPONSE"]._serialized_end = 1432
    _globals["_PICKINGTYPEREADREQUEST"]._serialized_start = 1435
    _globals["_PICKINGTYPEREADREQUEST"]._serialized_end = 1807
    _globals["_PICKINGTYPEREADRESPONSE"]._serialized_start = 1810
    _globals["_PICKINGTYPEREADRESPONSE"]._serialized_end = 2045
    _globals["_PICKINGTYPEUPDATEREQUEST"]._serialized_start = 2048
    _globals["_PICKINGTYPEUPDATEREQUEST"]._serialized_end = 2205
    _globals["_PICKINGTYPEUPDATERESPONSE"]._serialized_start = 2208
    _globals["_PICKINGTYPEUPDATERESPONSE"]._serialized_end = 2385
    _globals["_PICKINGTYPEDELETEREQUEST"]._serialized_start = 2387
    _globals["_PICKINGTYPEDELETEREQUEST"]._serialized_end = 2481
    _globals["_PICKINGTYPEDELETERESPONSE"]._serialized_start = 2483
    _globals["_PICKINGTYPEDELETERESPONSE"]._serialized_end = 2585
    _globals["_PICKINGTYPESERVICE"]._serialized_start = 2588
    _globals["_PICKINGTYPESERVICE"]._serialized_end = 3230
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.stock import stock_move_line_pb2 as v1_dot_stock_dot_stock__move__line__pb2


class StockMoveLineServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StockMoveLineCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLineService/StockMoveLineCreate",
            request_serializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineCreateResponse.FromString,
        )
        self.StockMoveLineRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLineService/StockMoveLineRead",
            request_serializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineReadResponse.FromString,
        )
        self.StockMoveLineUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLineService/StockMoveLineUpdate",
            request_serializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineUpdateResponse.FromString,
        )
        self.StockMoveLineDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLineService/StockMoveLineDelete",
            request_serializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineDeleteResponse.FromString,
        )


class StockMoveLineServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def StockMoveLineCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StockMoveLineRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StockMoveLineUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StockMoveLineDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_StockMoveLineServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "StockMoveLineCreate": grpc.unary_unary_rpc_method_handler(
            servicer.StockMoveLineCreate,
            request_deserializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineCreateResponse.SerializeToString,
        ),
        "StockMoveLineRead": grpc.unary_unary_rpc_method_handler(
            servicer.StockMoveLineRead,
            request_deserializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineReadResponse.SerializeToString,
        ),
        "StockMoveLineUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.StockMoveLineUpdate,
            request_deserializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineUpdateResponse.SerializeToString,
        ),
        "StockMoveLineDelete": grpc.unary_unary_rpc_method_handler(
            servicer.StockMoveLineDelete,
            request_deserializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLineService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class StockMoveLineService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def StockMoveLineCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLineService/StockMoveLineCreate",
            v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineCreateRequest.SerializeToString,
            v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def StockMoveLineRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLineService/StockMoveLineRead",
            v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineReadRequest.SerializeToString,
            v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def StockMoveLineUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLineService/StockMoveLineUpdate",
            v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineUpdateRequest.SerializeToString,
            v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def StockMoveLineDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLineService/StockMoveLineDelete",
            v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineDeleteRequest.SerializeToString,
            v1_dot_stock_dot_stock__move__line__pb2.StockMoveLineDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/sales/delivery_method.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1ev1/sales/delivery_method.proto\x12)pro.omni.oms.api.v1.sales.delivery.method\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xa5\x01\n\x0e\x44\x65liveryMethod\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12*\n\x06\x61\x63tive\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"q\n\x1b\x44\x65liveryMethodCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xbd\x01\n\x1c\x44\x65liveryMethodCreateResponse\x12R\n\x0f\x64\x65livery_method\x18\x01 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.sales.delivery.method.DeliveryMethod\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf7\x02\n\x19\x44\x65liveryMethodReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xf7\x01\n\x1a\x44\x65liveryMethodReadResponse\x12S\n\x10\x64\x65livery_methods\x18\x01 \x03(\x0b\x32\x39.pro.omni.oms.api.v1.sales.delivery.method.DeliveryMethod\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xa9\x01\n\x1b\x44\x65liveryMethodUpdateRequest\x12R\n\x0f\x64\x65livery_method\x18\x01 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.sales.delivery.method.DeliveryMethod\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xbd\x01\n\x1c\x44\x65liveryMethodUpdateResponse\x12R\n\x0f\x64\x65livery_method\x18\x01 \x01(\x0b\x32\x39.pro.omni.oms.api.v1.sales.delivery.method.DeliveryMethod\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"a\n\x1b\x44\x65liveryMethodDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"i\n\x1c\x44\x65liveryMethodDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xc1\x05\n\x15\x44\x65liveryMethodService\x12\xa9\x01\n\x14\x44\x65liveryMethodCreate\x12\x46.pro.omni.oms.api.v1.sales.delivery.method.DeliveryMethodCreateRequest\x1aG.pro.omni.oms.api.v1.sales.delivery.method.DeliveryMethodCreateResponse"\x00\x12\xa3\x01\n\x12\x44\x65liveryMethodRead\x12\x44.pro.omni.oms.api.v1.sales.delivery.method.DeliveryMethodReadRequest\x1a\x45.pro.omni.oms.api.v1.sales.delivery.method.DeliveryMethodReadResponse"\x00\x12\xa9\x01\n\x14\x44\x65liveryMethodUpdate\x12\x46.pro.omni.oms.api.v1.sales.delivery.method.DeliveryMethodUpdateRequest\x1aG.pro.omni.oms.api.v1.sales.delivery.method.DeliveryMethodUpdateResponse"\x00\x12\xa9\x01\n\x14\x44\x65liveryMethodDelete\x12\x46.pro.omni.oms.api.v1.sales.delivery.method.DeliveryMethodDeleteRequest\x1aG.pro.omni.oms.api.v1.sales.delivery.method.DeliveryMethodDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.sales.delivery_method_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DELIVERYMETHOD"]._serialized_start = 129
    _globals["_DELIVERYMETHOD"]._serialized_end = 294
    _globals["_DELIVERYMETHODCREATEREQUEST"]._serialized_start = 296
    _globals["_DELIVERYMETHODCREATEREQUEST"]._serialized_end = 409
    _globals["_DELIVERYMETHODCREATERESPONSE"]._serialized_start = 412
    _globals["_DELIVERYMETHODCREATERESPONSE"]._serialized_end = 601
    _globals["_DELIVERYMETHODREADREQUEST"]._serialized_start = 604
    _globals["_DELIVERYMETHODREADREQUEST"]._serialized_end = 979
    _globals["_DELIVERYMETHODREADRESPONSE"]._serialized_start = 982
    _globals["_DELIVERYMETHODREADRESPONSE"]._serialized_end = 1229
    _globals["_DELIVERYMETHODUPDATEREQUEST"]._serialized_start = 1232
    _globals["_DELIVERYMETHODUPDATEREQUEST"]._serialized_end = 1401
    _globals["_DELIVERYMETHODUPDATERESPONSE"]._serialized_start = 1404
    _globals["_DELIVERYMETHODUPDATERESPONSE"]._serialized_end = 1593
    _globals["_DELIVERYMETHODDELETEREQUEST"]._serialized_start = 1595
    _globals["_DELIVERYMETHODDELETEREQUEST"]._serialized_end = 1692
    _globals["_DELIVERYMETHODDELETERESPONSE"]._serialized_start = 1694
    _globals["_DELIVERYMETHODDELETERESPONSE"]._serialized_end = 1799
    _globals["_DELIVERYMETHODSERVICE"]._serialized_start = 1802
    _globals["_DELIVERYMETHODSERVICE"]._serialized_end = 2507
# @@protoc_insertion_point(module_scope)



from enum import Enum, unique
from pathlib import Path

from omni.pro import redis
from omni.pro.descriptor import Descriptor
from omni.pro.protos.grpc_function import ModelRPCFucntion
from omni.pro.topology import Topology
from omni.pro.util import generate_hash


@unique
class MicroService(Enum):
    SAAS_MS_USER = "saas-ms-user"
    SAAS_MS_CATALOG = "saas-ms-catalog"
    SAAS_MS_UTILITIES = "saas-ms-utilities"
    SAAS_MS_STOCK = "saas-ms-stock"
    SAAS_MS_CLIENT = "saas-ms-client"


class MicroServiceDocument(object):
    pass


class RegisterModel(object):
    def __init__(self, path_models: Path) -> None:
        self.path_models = path_models

    def register_model(self):
        l = Topology(path_models=self.path_models).get_models_from_libs()
        redis_manager = redis.get_redis_manager()
        tenans = redis_manager.get_tenant_codes()
        for tenant in tenans:
            user = redis_manager.get_json(tenant, "$.user_admin", "id")
            for model in l:
                desc = Descriptor.describe_mongo_model(model)
                hash_code = generate_hash(desc)
                context = {
                    "tenant": tenant,
                    "user": user,
                }
                ModelRPCFucntion(context=context).register_model(model, hash_code)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/stock_move_line.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1ev1/stock/stock_move_line.proto\x12)pro.omni.oms.api.v1.stock.stock_move_line\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\xfd\x02\n\rStockMoveLine\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x15\n\rstock_move_id\x18\x02 \x01(\x05\x12\x12\n\npicking_id\x18\x03 \x01(\x05\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x11\n\treference\x18\x05 \x01(\t\x12(\n\x04\x64\x61te\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06origin\x18\x07 \x01(\t\x12\x12\n\nproduct_id\x18\x08 \x01(\x05\x12\x13\n\x0blocation_id\x18\t \x01(\x05\x12\x18\n\x10location_dest_id\x18\n \x01(\x05\x12\x10\n\x08qty_done\x18\x0b \x01(\x05\x12\x16\n\x0eproduct_uom_id\x18\x0c \x01(\x05\x12*\n\x06\x61\x63tive\x18\r \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x0e \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xc9\x02\n\x1aStockMoveLineCreateRequest\x12\x15\n\rstock_move_id\x18\x01 \x01(\x05\x12\x12\n\npicking_id\x18\x02 \x01(\x05\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x11\n\treference\x18\x04 \x01(\t\x12(\n\x04\x64\x61te\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06origin\x18\x06 \x01(\t\x12\x12\n\nproduct_id\x18\x07 \x01(\x05\x12\x13\n\x0blocation_id\x18\x08 \x01(\x05\x12\x18\n\x10location_dest_id\x18\t \x01(\x05\x12\x10\n\x08qty_done\x18\n \x01(\x05\x12\x16\n\x0eproduct_uom_id\x18\x0b \x01(\x05\x12\x36\n\x07\x63ontext\x18\x0c \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xbb\x01\n\x1bStockMoveLineCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12Q\n\x0fstock_move_line\x18\x02 \x01(\x0b\x32\x38.pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLine"\xf6\x02\n\x18StockMoveLineReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xf5\x01\n\x19StockMoveLineReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12R\n\x10stock_move_lines\x18\x03 \x03(\x0b\x32\x38.pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLine"\xa7\x01\n\x1aStockMoveLineUpdateRequest\x12Q\n\x0fstock_move_line\x18\x01 \x01(\x0b\x32\x38.pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLine\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xbb\x01\n\x1bStockMoveLineUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12Q\n\x0fstock_move_line\x18\x02 \x01(\x0b\x32\x38.pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLine"`\n\x1aStockMoveLineDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"h\n\x1bStockMoveLineDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xac\x05\n\x14StockMoveLineService\x12\xa4\x01\n\x13StockMoveLineCreate\x12\x45.pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLineCreateRequest\x1a\x46.pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLineCreateResponse\x12\x9e\x01\n\x11StockMoveLineRead\x12\x43.pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLineReadRequest\x1a\x44.pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLineReadResponse\x12\xa4\x01\n\x13StockMoveLineUpdate\x12\x45.pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLineUpdateRequest\x1a\x46.pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLineUpdateResponse\x12\xa4\x01\n\x13StockMoveLineDelete\x12\x45.pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLineDeleteRequest\x1a\x46.pro.omni.oms.api.v1.stock.stock_move_line.StockMoveLineDeleteResponseb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.stock_move_line_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_STOCKMOVELINE"]._serialized_start = 162
    _globals["_STOCKMOVELINE"]._serialized_end = 543
    _globals["_STOCKMOVELINECREATEREQUEST"]._serialized_start = 546
    _globals["_STOCKMOVELINECREATEREQUEST"]._serialized_end = 875
    _globals["_STOCKMOVELINECREATERESPONSE"]._serialized_start = 878
    _globals["_STOCKMOVELINECREATERESPONSE"]._serialized_end = 1065
    _globals["_STOCKMOVELINEREADREQUEST"]._serialized_start = 1068
    _globals["_STOCKMOVELINEREADREQUEST"]._serialized_end = 1442
    _globals["_STOCKMOVELINEREADRESPONSE"]._serialized_start = 1445
    _globals["_STOCKMOVELINEREADRESPONSE"]._serialized_end = 1690
    _globals["_STOCKMOVELINEUPDATEREQUEST"]._serialized_start = 1693
    _globals["_STOCKMOVELINEUPDATEREQUEST"]._serialized_end = 1860
    _globals["_STOCKMOVELINEUPDATERESPONSE"]._serialized_start = 1863
    _globals["_STOCKMOVELINEUPDATERESPONSE"]._serialized_end = 2050
    _globals["_STOCKMOVELINEDELETEREQUEST"]._serialized_start = 2052
    _globals["_STOCKMOVELINEDELETEREQUEST"]._serialized_end = 2148
    _globals["_STOCKMOVELINEDELETERESPONSE"]._serialized_start = 2150
    _globals["_STOCKMOVELINEDELETERESPONSE"]._serialized_end = 2254
    _globals["_STOCKMOVELINESERVICE"]._serialized_start = 2257
    _globals["_STOCKMOVELINESERVICE"]._serialized_end = 2941
# @@protoc_insertion_point(module_scope)



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class Sale(_message.Message):
    __slots__ = [
        "id",
        "name",
        "date_order",
        "origin",
        "channel_id",
        "currency_id",
        "confirm_date",
        "client_id",
        "bill_address_id",
        "country_id",
        "warehouse_id",
        "json_order",
        "active",
        "object_audit",
    ]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DATE_ORDER_FIELD_NUMBER: _ClassVar[int]
    ORIGIN_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    CURRENCY_ID_FIELD_NUMBER: _ClassVar[int]
    CONFIRM_DATE_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    BILL_ADDRESS_ID_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_ID_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSE_ID_FIELD_NUMBER: _ClassVar[int]
    JSON_ORDER_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    id: int
    name: str
    date_order: _timestamp_pb2.Timestamp
    origin: str
    channel_id: int
    currency_id: int
    confirm_date: _timestamp_pb2.Timestamp
    client_id: int
    bill_address_id: int
    country_id: int
    warehouse_id: int
    json_order: str
    active: _wrappers_pb2.BoolValue
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        id: _Optional[int] = ...,
        name: _Optional[str] = ...,
        date_order: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        origin: _Optional[str] = ...,
        channel_id: _Optional[int] = ...,
        currency_id: _Optional[int] = ...,
        confirm_date: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        client_id: _Optional[int] = ...,
        bill_address_id: _Optional[int] = ...,
        country_id: _Optional[int] = ...,
        warehouse_id: _Optional[int] = ...,
        json_order: _Optional[str] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class SaleCreateRequest(_message.Message):
    __slots__ = [
        "name",
        "date_order",
        "origin",
        "channel_id",
        "currency_id",
        "confirm_date",
        "client_id",
        "bill_address_id",
        "country_id",
        "warehouse_id",
        "json_order",
        "context",
    ]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DATE_ORDER_FIELD_NUMBER: _ClassVar[int]
    ORIGIN_FIELD_NUMBER: _ClassVar[int]
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    CURRENCY_ID_FIELD_NUMBER: _ClassVar[int]
    CONFIRM_DATE_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    BILL_ADDRESS_ID_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_ID_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSE_ID_FIELD_NUMBER: _ClassVar[int]
    JSON_ORDER_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    name: str
    date_order: _timestamp_pb2.Timestamp
    origin: str
    channel_id: int
    currency_id: int
    confirm_date: _timestamp_pb2.Timestamp
    client_id: int
    bill_address_id: int
    country_id: int
    warehouse_id: int
    json_order: str
    context: _base_pb2.Context
    def __init__(
        self,
        name: _Optional[str] = ...,
        date_order: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        origin: _Optional[str] = ...,
        channel_id: _Optional[int] = ...,
        currency_id: _Optional[int] = ...,
        confirm_date: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        client_id: _Optional[int] = ...,
        bill_address_id: _Optional[int] = ...,
        country_id: _Optional[int] = ...,
        warehouse_id: _Optional[int] = ...,
        json_order: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class SaleCreateResponse(_message.Message):
    __slots__ = ["sale", "response_standard"]
    SALE_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    sale: Sale
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        sale: _Optional[_Union[Sale, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class SaleReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: int
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class SaleReadResponse(_message.Message):
    __slots__ = ["sale", "response_standard", "meta_data"]
    SALE_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    sale: _containers.RepeatedCompositeFieldContainer[Sale]
    response_standard: _base_pb2.ResponseStandard
    meta_data: _base_pb2.MetaData
    def __init__(
        self,
        sale: _Optional[_Iterable[_Union[Sale, _Mapping]]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
    ) -> None: ...

class SaleUpdateRequest(_message.Message):
    __slots__ = ["sale", "context"]
    SALE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    sale: Sale
    context: _base_pb2.Context
    def __init__(
        self,
        sale: _Optional[_Union[Sale, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class SaleUpdateResponse(_message.Message):
    __slots__ = ["sale", "response_standard"]
    SALE_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    sale: Sale
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        sale: _Optional[_Union[Sale, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class SaleDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: int
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[int] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class SaleDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/quant.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x14v1/stock/quant.proto\x12\x1fpro.omni.oms.api.v1.stock.quant\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xf5\x01\n\x05Quant\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nproduct_id\x18\x02 \x01(\x05\x12\x13\n\x0blocation_id\x18\x03 \x01(\x05\x12\x0c\n\x04lote\x18\x04 \x01(\t\x12\x1a\n\x12\x61vailable_quantity\x18\x05 \x01(\x02\x12\x10\n\x08quantity\x18\x06 \x01(\x02\x12\x0e\n\x06uom_id\x18\x07 \x01(\x05\x12*\n\x06\x61\x63tive\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\t \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xdc\x01\n\x12QuantCreateRequest\x12\x12\n\nproduct_id\x18\x01 \x01(\x05\x12\x13\n\x0blocation_id\x18\x02 \x01(\x05\x12\x0c\n\x04lote\x18\x03 \x01(\t\x12\x1a\n\x12\x61vailable_quantity\x18\x04 \x01(\x02\x12\x10\n\x08quantity\x18\x05 \x01(\x02\x12\x0e\n\x06uom_id\x18\x06 \x01(\x05\x12\x19\n\x11reserved_quantity\x18\x07 \x01(\x02\x12\x36\n\x07\x63ontext\x18\x08 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x97\x01\n\x13QuantCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x35\n\x05quant\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.stock.quant.Quant"\xee\x02\n\x10QuantReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd1\x01\n\x11QuantReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x36\n\x06quants\x18\x03 \x03(\x0b\x32&.pro.omni.oms.api.v1.stock.quant.Quant"\x83\x01\n\x12QuantUpdateRequest\x12\x35\n\x05quant\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.stock.quant.Quant\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x97\x01\n\x13QuantUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x35\n\x05quant\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.stock.quant.Quant"X\n\x12QuantDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"`\n\x13QuantDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xf8\x03\n\x0cQuantService\x12z\n\x0bQuantCreate\x12\x33.pro.omni.oms.api.v1.stock.quant.QuantCreateRequest\x1a\x34.pro.omni.oms.api.v1.stock.quant.QuantCreateResponse"\x00\x12t\n\tQuantRead\x12\x31.pro.omni.oms.api.v1.stock.quant.QuantReadRequest\x1a\x32.pro.omni.oms.api.v1.stock.quant.QuantReadResponse"\x00\x12z\n\x0bQuantUpdate\x12\x33.pro.omni.oms.api.v1.stock.quant.QuantUpdateRequest\x1a\x34.pro.omni.oms.api.v1.stock.quant.QuantUpdateResponse"\x00\x12z\n\x0bQuantDelete\x12\x33.pro.omni.oms.api.v1.stock.quant.QuantDeleteRequest\x1a\x34.pro.omni.oms.api.v1.stock.quant.QuantDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.quant_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_QUANT"]._serialized_start = 109
    _globals["_QUANT"]._serialized_end = 354
    _globals["_QUANTCREATEREQUEST"]._serialized_start = 357
    _globals["_QUANTCREATEREQUEST"]._serialized_end = 577
    _globals["_QUANTCREATERESPONSE"]._serialized_start = 580
    _globals["_QUANTCREATERESPONSE"]._serialized_end = 731
    _globals["_QUANTREADREQUEST"]._serialized_start = 734
    _globals["_QUANTREADREQUEST"]._serialized_end = 1100
    _globals["_QUANTREADRESPONSE"]._serialized_start = 1103
    _globals["_QUANTREADRESPONSE"]._serialized_end = 1312
    _globals["_QUANTUPDATEREQUEST"]._serialized_start = 1315
    _globals["_QUANTUPDATEREQUEST"]._serialized_end = 1446
    _globals["_QUANTUPDATERESPONSE"]._serialized_start = 1449
    _globals["_QUANTUPDATERESPONSE"]._serialized_end = 1600
    _globals["_QUANTDELETEREQUEST"]._serialized_start = 1602
    _globals["_QUANTDELETEREQUEST"]._serialized_end = 1690
    _globals["_QUANTDELETERESPONSE"]._serialized_start = 1692
    _globals["_QUANTDELETERESPONSE"]._serialized_end = 1788
    _globals["_QUANTSERVICE"]._serialized_start = 1791
    _globals["_QUANTSERVICE"]._serialized_end = 2295
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.utilities import tax_pb2 as v1_dot_utilities_dot_tax__pb2


class TaxServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.TaxAdd = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.tax.TaxService/TaxAdd",
            request_serializer=v1_dot_utilities_dot_tax__pb2.TaxAddRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_tax__pb2.TaxAddResponse.FromString,
        )
        self.TaxRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.tax.TaxService/TaxRead",
            request_serializer=v1_dot_utilities_dot_tax__pb2.TaxReadRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_tax__pb2.TaxReadResponse.FromString,
        )
        self.TaxUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.tax.TaxService/TaxUpdate",
            request_serializer=v1_dot_utilities_dot_tax__pb2.TaxUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_tax__pb2.TaxUpdateResponse.FromString,
        )
        self.TaxDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.tax.TaxService/TaxDelete",
            request_serializer=v1_dot_utilities_dot_tax__pb2.TaxDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_tax__pb2.TaxDeleteResponse.FromString,
        )


class TaxServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def TaxAdd(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def TaxRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def TaxUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def TaxDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_TaxServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "TaxAdd": grpc.unary_unary_rpc_method_handler(
            servicer.TaxAdd,
            request_deserializer=v1_dot_utilities_dot_tax__pb2.TaxAddRequest.FromString,
            response_serializer=v1_dot_utilities_dot_tax__pb2.TaxAddResponse.SerializeToString,
        ),
        "TaxRead": grpc.unary_unary_rpc_method_handler(
            servicer.TaxRead,
            request_deserializer=v1_dot_utilities_dot_tax__pb2.TaxReadRequest.FromString,
            response_serializer=v1_dot_utilities_dot_tax__pb2.TaxReadResponse.SerializeToString,
        ),
        "TaxUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.TaxUpdate,
            request_deserializer=v1_dot_utilities_dot_tax__pb2.TaxUpdateRequest.FromString,
            response_serializer=v1_dot_utilities_dot_tax__pb2.TaxUpdateResponse.SerializeToString,
        ),
        "TaxDelete": grpc.unary_unary_rpc_method_handler(
            servicer.TaxDelete,
            request_deserializer=v1_dot_utilities_dot_tax__pb2.TaxDeleteRequest.FromString,
            response_serializer=v1_dot_utilities_dot_tax__pb2.TaxDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.utilities.tax.TaxService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class TaxService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def TaxAdd(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.tax.TaxService/TaxAdd",
            v1_dot_utilities_dot_tax__pb2.TaxAddRequest.SerializeToString,
            v1_dot_utilities_dot_tax__pb2.TaxAddResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def TaxRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.tax.TaxService/TaxRead",
            v1_dot_utilities_dot_tax__pb2.TaxReadRequest.SerializeToString,
            v1_dot_utilities_dot_tax__pb2.TaxReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def TaxUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.tax.TaxService/TaxUpdate",
            v1_dot_utilities_dot_tax__pb2.TaxUpdateRequest.SerializeToString,
            v1_dot_utilities_dot_tax__pb2.TaxUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def TaxDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.tax.TaxService/TaxDelete",
            v1_dot_utilities_dot_tax__pb2.TaxDeleteRequest.SerializeToString,
            v1_dot_utilities_dot_tax__pb2.TaxDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import delivery_warehouse_pb2 as v1_dot_rules_dot_delivery__warehouse__pb2


class DeliveryWarehouseServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeliveryWarehouseCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouseService/DeliveryWarehouseCreate",
            request_serializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseCreateResponse.FromString,
        )
        self.DeliveryWarehouseRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouseService/DeliveryWarehouseRead",
            request_serializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseReadResponse.FromString,
        )
        self.DeliveryWarehouseUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouseService/DeliveryWarehouseUpdate",
            request_serializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseUpdateResponse.FromString,
        )
        self.DeliveryWarehouseDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouseService/DeliveryWarehouseDelete",
            request_serializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseDeleteResponse.FromString,
        )


class DeliveryWarehouseServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeliveryWarehouseCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryWarehouseRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryWarehouseUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryWarehouseDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DeliveryWarehouseServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DeliveryWarehouseCreate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryWarehouseCreate,
            request_deserializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseCreateResponse.SerializeToString,
        ),
        "DeliveryWarehouseRead": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryWarehouseRead,
            request_deserializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseReadResponse.SerializeToString,
        ),
        "DeliveryWarehouseUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryWarehouseUpdate,
            request_deserializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseUpdateResponse.SerializeToString,
        ),
        "DeliveryWarehouseDelete": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryWarehouseDelete,
            request_deserializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouseService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class DeliveryWarehouseService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeliveryWarehouseCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouseService/DeliveryWarehouseCreate",
            v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseCreateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryWarehouseRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouseService/DeliveryWarehouseRead",
            v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseReadRequest.SerializeToString,
            v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryWarehouseUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouseService/DeliveryWarehouseUpdate",
            v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseUpdateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryWarehouseDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_warehouse.DeliveryWarehouseService/DeliveryWarehouseDelete",
            v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseDeleteRequest.SerializeToString,
            v1_dot_rules_dot_delivery__warehouse__pb2.DeliveryWarehouseDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delivery_category.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.rules import category_pb2 as v1_dot_rules_dot_category__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n v1/rules/delivery_category.proto\x12+pro.omni.oms.api.v1.rules.delivery_category\x1a\x11\x63ommon/base.proto\x1a\x17v1/rules/category.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xdb\x01\n\x10\x44\x65liveryCategory\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12@\n\ncategories\x18\x03 \x03(\x0b\x32,.pro.omni.oms.api.v1.rules.category.Category\x12*\n\x06\x61\x63tive\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"{\n\x1d\x44\x65liveryCategoryCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x63\x61tegory_ids\x18\x02 \x03(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc5\x01\n\x1e\x44\x65liveryCategoryCreateResponse\x12X\n\x11\x64\x65livery_category\x18\x01 \x01(\x0b\x32=.pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategory\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf9\x02\n\x1b\x44\x65liveryCategoryReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x80\x02\n\x1c\x44\x65liveryCategoryReadResponse\x12Z\n\x13\x64\x65livery_categories\x18\x01 \x03(\x0b\x32=.pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategory\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xb1\x01\n\x1d\x44\x65liveryCategoryUpdateRequest\x12X\n\x11\x64\x65livery_category\x18\x01 \x01(\x0b\x32=.pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategory\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc5\x01\n\x1e\x44\x65liveryCategoryUpdateResponse\x12X\n\x11\x64\x65livery_category\x18\x01 \x01(\x0b\x32=.pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategory\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"c\n\x1d\x44\x65liveryCategoryDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"k\n\x1e\x44\x65liveryCategoryDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xeb\x05\n\x17\x44\x65liveryCategoryService\x12\xb3\x01\n\x16\x44\x65liveryCategoryCreate\x12J.pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategoryCreateRequest\x1aK.pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategoryCreateResponse"\x00\x12\xad\x01\n\x14\x44\x65liveryCategoryRead\x12H.pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategoryReadRequest\x1aI.pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategoryReadResponse"\x00\x12\xb3\x01\n\x16\x44\x65liveryCategoryUpdate\x12J.pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategoryUpdateRequest\x1aK.pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategoryUpdateResponse"\x00\x12\xb3\x01\n\x16\x44\x65liveryCategoryDelete\x12J.pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategoryDeleteRequest\x1aK.pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategoryDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delivery_category_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DELIVERYCATEGORY"]._serialized_start = 158
    _globals["_DELIVERYCATEGORY"]._serialized_end = 377
    _globals["_DELIVERYCATEGORYCREATEREQUEST"]._serialized_start = 379
    _globals["_DELIVERYCATEGORYCREATEREQUEST"]._serialized_end = 502
    _globals["_DELIVERYCATEGORYCREATERESPONSE"]._serialized_start = 505
    _globals["_DELIVERYCATEGORYCREATERESPONSE"]._serialized_end = 702
    _globals["_DELIVERYCATEGORYREADREQUEST"]._serialized_start = 705
    _globals["_DELIVERYCATEGORYREADREQUEST"]._serialized_end = 1082
    _globals["_DELIVERYCATEGORYREADRESPONSE"]._serialized_start = 1085
    _globals["_DELIVERYCATEGORYREADRESPONSE"]._serialized_end = 1341
    _globals["_DELIVERYCATEGORYUPDATEREQUEST"]._serialized_start = 1344
    _globals["_DELIVERYCATEGORYUPDATEREQUEST"]._serialized_end = 1521
    _globals["_DELIVERYCATEGORYUPDATERESPONSE"]._serialized_start = 1524
    _globals["_DELIVERYCATEGORYUPDATERESPONSE"]._serialized_end = 1721
    _globals["_DELIVERYCATEGORYDELETEREQUEST"]._serialized_start = 1723
    _globals["_DELIVERYCATEGORYDELETEREQUEST"]._serialized_end = 1822
    _globals["_DELIVERYCATEGORYDELETERESPONSE"]._serialized_start = 1824
    _globals["_DELIVERYCATEGORYDELETERESPONSE"]._serialized_end = 1931
    _globals["_DELIVERYCATEGORYSERVICE"]._serialized_start = 1934
    _globals["_DELIVERYCATEGORYSERVICE"]._serialized_end = 2681
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delivery_schedule.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.rules import schedule_work_pb2 as v1_dot_rules_dot_schedule__work__pb2
from omni.pro.protos.v1.rules import warehouse_hierarchy_pb2 as v1_dot_rules_dot_warehouse__hierarchy__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n v1/rules/delivery_schedule.proto\x12+pro.omni.oms.api.v1.rules.delivery_schedule\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a"v1/rules/warehouse_hierarchy.proto\x1a\x1cv1/rules/schedule_work.proto"\xea\x01\n\x10\x44\x65liverySchedule\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12O\n\x10schedule_work_id\x18\x03 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWork\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x7f\n\x1d\x44\x65liveryScheduleCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x10schedule_work_id\x18\x02 \x01(\t\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc5\x01\n\x1e\x44\x65liveryScheduleCreateResponse\x12X\n\x11\x64\x65livery_schedule\x18\x01 \x01(\x0b\x32=.pro.omni.oms.api.v1.rules.delivery_schedule.DeliverySchedule\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf9\x02\n\x1b\x44\x65liveryScheduleReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xff\x01\n\x1c\x44\x65liveryScheduleReadResponse\x12Y\n\x12\x64\x65livery_schedules\x18\x01 \x03(\x0b\x32=.pro.omni.oms.api.v1.rules.delivery_schedule.DeliverySchedule\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xb1\x01\n\x1d\x44\x65liveryScheduleUpdateRequest\x12X\n\x11\x64\x65livery_schedule\x18\x01 \x01(\x0b\x32=.pro.omni.oms.api.v1.rules.delivery_schedule.DeliverySchedule\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc5\x01\n\x1e\x44\x65liveryScheduleUpdateResponse\x12X\n\x11\x64\x65livery_schedule\x18\x01 \x01(\x0b\x32=.pro.omni.oms.api.v1.rules.delivery_schedule.DeliverySchedule\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"c\n\x1d\x44\x65liveryScheduleDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"k\n\x1e\x44\x65liveryScheduleDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xeb\x05\n\x17\x44\x65liveryScheduleService\x12\xb3\x01\n\x16\x44\x65liveryScheduleCreate\x12J.pro.omni.oms.api.v1.rules.delivery_schedule.DeliveryScheduleCreateRequest\x1aK.pro.omni.oms.api.v1.rules.delivery_schedule.DeliveryScheduleCreateResponse"\x00\x12\xad\x01\n\x14\x44\x65liveryScheduleRead\x12H.pro.omni.oms.api.v1.rules.delivery_schedule.DeliveryScheduleReadRequest\x1aI.pro.omni.oms.api.v1.rules.delivery_schedule.DeliveryScheduleReadResponse"\x00\x12\xb3\x01\n\x16\x44\x65liveryScheduleUpdate\x12J.pro.omni.oms.api.v1.rules.delivery_schedule.DeliveryScheduleUpdateRequest\x1aK.pro.omni.oms.api.v1.rules.delivery_schedule.DeliveryScheduleUpdateResponse"\x00\x12\xb3\x01\n\x16\x44\x65liveryScheduleDelete\x12J.pro.omni.oms.api.v1.rules.delivery_schedule.DeliveryScheduleDeleteRequest\x1aK.pro.omni.oms.api.v1.rules.delivery_schedule.DeliveryScheduleDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delivery_schedule_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DELIVERYSCHEDULE"]._serialized_start = 199
    _globals["_DELIVERYSCHEDULE"]._serialized_end = 433
    _globals["_DELIVERYSCHEDULECREATEREQUEST"]._serialized_start = 435
    _globals["_DELIVERYSCHEDULECREATEREQUEST"]._serialized_end = 562
    _globals["_DELIVERYSCHEDULECREATERESPONSE"]._serialized_start = 565
    _globals["_DELIVERYSCHEDULECREATERESPONSE"]._serialized_end = 762
    _globals["_DELIVERYSCHEDULEREADREQUEST"]._serialized_start = 765
    _globals["_DELIVERYSCHEDULEREADREQUEST"]._serialized_end = 1142
    _globals["_DELIVERYSCHEDULEREADRESPONSE"]._serialized_start = 1145
    _globals["_DELIVERYSCHEDULEREADRESPONSE"]._serialized_end = 1400
    _globals["_DELIVERYSCHEDULEUPDATEREQUEST"]._serialized_start = 1403
    _globals["_DELIVERYSCHEDULEUPDATEREQUEST"]._serialized_end = 1580
    _globals["_DELIVERYSCHEDULEUPDATERESPONSE"]._serialized_start = 1583
    _globals["_DELIVERYSCHEDULEUPDATERESPONSE"]._serialized_end = 1780
    _globals["_DELIVERYSCHEDULEDELETEREQUEST"]._serialized_start = 1782
    _globals["_DELIVERYSCHEDULEDELETEREQUEST"]._serialized_end = 1881
    _globals["_DELIVERYSCHEDULEDELETERESPONSE"]._serialized_start = 1883
    _globals["_DELIVERYSCHEDULEDELETERESPONSE"]._serialized_end = 1990
    _globals["_DELIVERYSCHEDULESERVICE"]._serialized_start = 1993
    _globals["_DELIVERYSCHEDULESERVICE"]._serialized_end = 2740
# @@protoc_insertion_point(module_scope)



from datetime import datetime

from google.protobuf.timestamp_pb2 import Timestamp
from mongoengine import BooleanField, DateTimeField, Document, EmbeddedDocument, EmbeddedDocumentField, StringField
from omni.pro.protos.common.base_pb2 import Context as ContextProto
from omni.pro.protos.common.base_pb2 import Object as ObjectProto
from omni.pro.protos.common.base_pb2 import ObjectAudit as AuditProto
from sqlalchemy import Boolean, DateTime, ForeignKey, String
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import DeclarativeBase, Mapped, declarative_mixin, declared_attr, mapped_column, relationship


class BaseEmbeddedDocument(EmbeddedDocument):
    meta = {
        "abstract": True,
        "strict": False,
    }

    def to_proto(self, *args, **kwargs):
        raise NotImplementedError


class BaseObjectEmbeddedDocument(BaseEmbeddedDocument):
    code = StringField()
    code_name = StringField()
    meta = {
        "allow_inheritance": True,
    }

    def to_proto(self):
        return ObjectProto(
            code=self.code,
            code_name=self.code_name,
        )


class Audit(BaseEmbeddedDocument):
    created_at = DateTimeField(default=datetime.utcnow)
    created_by = StringField()
    updated_at = DateTimeField()
    updated_by = StringField()
    deleted_at = DateTimeField()
    deleted_by = StringField()

    def to_proto(self) -> AuditProto:
        create_at_ts = Timestamp()
        create_at_ts.FromDatetime(self.created_at)
        update_at_ts = Timestamp()
        update_at_ts.FromDatetime(self.updated_at)
        return AuditProto(
            created_by=self.created_by,
            updated_by=self.updated_by,
            created_at=create_at_ts,
            updated_at=update_at_ts,
        )


class Context(BaseEmbeddedDocument):
    tenant = StringField()
    user = StringField()

    def to_proto(self) -> ContextProto:
        return ContextProto(
            tenant=self.tenant,
            user=self.user,
        )


class BaseDocument(Document):
    context = EmbeddedDocumentField(Context)
    audit = EmbeddedDocumentField(Audit)
    active = BooleanField(default=True)

    meta = {
        "abstract": True,
        "strict": False,
    }

    @classmethod
    @property
    def db(cls):
        return cls._get_db()

    def save(self, *args, **kwargs):
        if not self.context:
            self.context = Context()
        if not self.audit:
            self.audit = Audit(created_by=self.context.user)
        self.audit.updated_by = self.context.user
        self.audit.updated_at = datetime.utcnow()
        return super().save(*args, **kwargs)

    def to_proto(self, *args, **kwargs):
        raise NotImplementedError

    @classmethod
    def reference_list(cls):
        return [cls]


class BaseAuditEmbeddedDocument(BaseEmbeddedDocument):
    context = EmbeddedDocumentField(Context)
    audit = EmbeddedDocumentField(Audit)
    active = BooleanField(default=True)
    meta = {
        "abstract": True,
        "strict": False,
    }

    # TODO: Add a method to update the audit fields
    def save(self, *args, **kwargs):
        if not self.context:
            self.context = Context()
        if not self.audit:
            self.audit = Audit(created_by=self.context.user)
        self.audit.updated_by = self.context.user
        self.audit.updated_at = datetime.utcnow()
        return super().save(*args, **kwargs)


BaseAuditContextEmbeddedDocument = BaseAuditEmbeddedDocument


def set_created_by(context):
    params = context.get_current_parameters()
    if params.get("created_by") is None:
        return params.get("updated_by")
    return params.get("created_by")


class Base:
    @declared_attr
    def __tablename__(cls):
        return cls.__name__.lower()

    id: Mapped[int] = mapped_column(primary_key=True, autoincrement=True)
    active: Mapped[bool] = mapped_column(Boolean, default=True, nullable=False)
    tenant: Mapped[str] = mapped_column(String(30), nullable=False)
    created_by: Mapped[str] = mapped_column(String(50), default=set_created_by, nullable=False)
    updated_by: Mapped[str] = mapped_column(String(50), nullable=False)
    deleted_by: Mapped[str] = mapped_column(String(50), nullable=True)
    created_at: Mapped[datetime] = mapped_column(DateTime(), default=datetime.now, nullable=False)
    updated_at: Mapped[datetime] = mapped_column(
        DateTime(), default=datetime.now, onupdate=datetime.now, nullable=False
    )
    deleted_at: Mapped[datetime] = mapped_column(DateTime(), nullable=True)

    def to_proto(self) -> AuditProto:
        create_at_ts = Timestamp()
        create_at_ts.FromDatetime(self.created_at)
        update_at_ts = Timestamp()
        update_at_ts.FromDatetime(self.updated_at)
        audit_proto = AuditProto(
            created_by=self.created_by,
            updated_by=self.updated_by,
            created_at=create_at_ts,
            updated_at=update_at_ts,
        )
        if self.deleted_at:
            deleted_at_ts = Timestamp()
            deleted_at_ts.FromDatetime(self.deleted_at)
            audit_proto.deleted_at = deleted_at_ts

        return audit_proto

    def sync_data(self, *args, **kwargs):
        raise NotImplementedError

    def get_or_sync(self, *args, **kwargs):
        raise NotImplementedError

    def get_document_info(self, *args, **kwargs):
        raise NotImplementedError


BaseModel = declarative_base(cls=Base)



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2
from omni.pro.protos.v1.rules import category_pb2 as _category_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class DeliveryCategory(_message.Message):
    __slots__ = ["id", "name", "categories", "active", "object_audit"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CATEGORIES_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    categories: _containers.RepeatedCompositeFieldContainer[_category_pb2.Category]
    active: _wrappers_pb2.BoolValue
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        id: _Optional[str] = ...,
        name: _Optional[str] = ...,
        categories: _Optional[_Iterable[_Union[_category_pb2.Category, _Mapping]]] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class DeliveryCategoryCreateRequest(_message.Message):
    __slots__ = ["name", "category_ids", "context"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CATEGORY_IDS_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    name: str
    category_ids: _containers.RepeatedScalarFieldContainer[str]
    context: _base_pb2.Context
    def __init__(
        self,
        name: _Optional[str] = ...,
        category_ids: _Optional[_Iterable[str]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class DeliveryCategoryCreateResponse(_message.Message):
    __slots__ = ["delivery_category", "response_standard"]
    DELIVERY_CATEGORY_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    delivery_category: DeliveryCategory
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        delivery_category: _Optional[_Union[DeliveryCategory, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class DeliveryCategoryReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: str
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class DeliveryCategoryReadResponse(_message.Message):
    __slots__ = ["delivery_categories", "meta_data", "response_standard"]
    DELIVERY_CATEGORIES_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    delivery_categories: _containers.RepeatedCompositeFieldContainer[DeliveryCategory]
    meta_data: _base_pb2.MetaData
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        delivery_categories: _Optional[_Iterable[_Union[DeliveryCategory, _Mapping]]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class DeliveryCategoryUpdateRequest(_message.Message):
    __slots__ = ["delivery_category", "context"]
    DELIVERY_CATEGORY_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    delivery_category: DeliveryCategory
    context: _base_pb2.Context
    def __init__(
        self,
        delivery_category: _Optional[_Union[DeliveryCategory, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class DeliveryCategoryUpdateResponse(_message.Message):
    __slots__ = ["delivery_category", "response_standard"]
    DELIVERY_CATEGORY_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    delivery_category: DeliveryCategory
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        delivery_category: _Optional[_Union[DeliveryCategory, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class DeliveryCategoryDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: str
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[str] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class DeliveryCategoryDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import delivery_category_pb2 as v1_dot_rules_dot_delivery__category__pb2


class DeliveryCategoryServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeliveryCategoryCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategoryService/DeliveryCategoryCreate",
            request_serializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryCreateResponse.FromString,
        )
        self.DeliveryCategoryRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategoryService/DeliveryCategoryRead",
            request_serializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryReadResponse.FromString,
        )
        self.DeliveryCategoryUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategoryService/DeliveryCategoryUpdate",
            request_serializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryUpdateResponse.FromString,
        )
        self.DeliveryCategoryDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategoryService/DeliveryCategoryDelete",
            request_serializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryDeleteResponse.FromString,
        )


class DeliveryCategoryServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeliveryCategoryCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryCategoryRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryCategoryUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryCategoryDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DeliveryCategoryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DeliveryCategoryCreate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryCategoryCreate,
            request_deserializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryCreateResponse.SerializeToString,
        ),
        "DeliveryCategoryRead": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryCategoryRead,
            request_deserializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryReadResponse.SerializeToString,
        ),
        "DeliveryCategoryUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryCategoryUpdate,
            request_deserializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryUpdateResponse.SerializeToString,
        ),
        "DeliveryCategoryDelete": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryCategoryDelete,
            request_deserializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategoryService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class DeliveryCategoryService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeliveryCategoryCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategoryService/DeliveryCategoryCreate",
            v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryCreateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryCategoryRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategoryService/DeliveryCategoryRead",
            v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryReadRequest.SerializeToString,
            v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryCategoryUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategoryService/DeliveryCategoryUpdate",
            v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryUpdateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryCategoryDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategoryService/DeliveryCategoryDelete",
            v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryDeleteRequest.SerializeToString,
            v1_dot_rules_dot_delivery__category__pb2.DeliveryCategoryDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
